@@ -1,17 +1,21 @@
 from .base_reducer import BaseReducer
 from .mean_reducer import MeanReducer
 import torch
-from ..utils import common_functions as c_f
+
 
 class MultipleReducers(BaseReducer):
     def __init__(self, reducers, default_reducer=None, **kwargs):
         super().__init__(**kwargs)
         self.reducers = torch.nn.ModuleDict(reducers)
-        self.default_reducer = MeanReducer() if default_reducer is None else default_reducer
+        self.default_reducer = (
+            MeanReducer() if default_reducer is None else default_reducer
+        )
 
     def forward(self, loss_dict, embeddings, labels):
         self.reset_stats()
-        sub_losses = torch.zeros(len(loss_dict), dtype=embeddings.dtype).to(embeddings.device)
+        sub_losses = torch.zeros(len(loss_dict), dtype=embeddings.dtype).to(
+            embeddings.device
+        )
         loss_count = 0
         for loss_name, loss_info in loss_dict.items():
             input_dict = {loss_name: loss_info}
@@ -21,7 +25,7 @@ class MultipleReducers(BaseReducer):
                 loss_val = self.default_reducer(input_dict, embeddings, labels)
             sub_losses[loss_count] = loss_val
             loss_count += 1
-        return self.sub_loss_reduction(sub_losses, embeddings, labels)            
+        return self.sub_loss_reduction(sub_losses, embeddings, labels)
 
     def sub_loss_reduction(self, sub_losses, embeddings=None, labels=None):
         return torch.sum(sub_losses)
