@@ -1,13 +1,12 @@
-#! /usr/bin/env python3
-import sys
 import logging
+
 try:
     import faiss
 except ModuleNotFoundError:
-    logging.error("""The testing module requires faiss. You can install the GPU version with the command 'conda install faiss-gpu -c pytorch' 
-                        or the CPU version with 'conda install faiss-cpu -c pytorch'. Learn more at https://github.com/facebookresearch/faiss/blob/master/INSTALL.md""")
-import torch
-import numpy as np
+    logging.warning(
+        """The pytorch-metric-learning testing module requires faiss. You can install the GPU version with the command 'conda install faiss-gpu -c pytorch' 
+                        or the CPU version with 'conda install faiss-cpu -c pytorch'. Learn more at https://github.com/facebookresearch/faiss/blob/master/INSTALL.md"""
+    )
 
 # modified from https://github.com/facebookresearch/deepcluster
 def get_knn(
@@ -23,18 +22,21 @@ def get_knn(
         embeddings_come_from_same_source: if True, then the nearest neighbor of
                                          each element (which is actually itself)
                                          will be ignored.
+    Returns:
+        numpy array: indices of nearest k neighbors
+        numpy array: corresponding distances
     """
     d = reference_embeddings.shape[1]
-    logging.info("running k-nn with k=%d"%k)
-    logging.info("embedding dimensionality is %d"%d)
+    logging.info("running k-nn with k=%d" % k)
+    logging.info("embedding dimensionality is %d" % d)
     index = faiss.IndexFlatL2(d)
     if faiss.get_num_gpus() > 0:
         index = faiss.index_cpu_to_all_gpus(index)
     index.add(reference_embeddings)
-    _, indices = index.search(test_embeddings, k + 1)
+    distances, indices = index.search(test_embeddings, k + 1)
     if embeddings_come_from_same_source:
-        return indices[:, 1:]
-    return indices[:, :k]
+        return indices[:, 1:], distances[:, 1:]
+    return indices[:, :k], distances[:, :k]
 
 
 # modified from https://raw.githubusercontent.com/facebookresearch/deepcluster/
@@ -47,6 +49,8 @@ def run_kmeans(x, nmb_clusters):
         list: ids of data in each cluster
     """
     n_data, d = x.shape
+    logging.info("running k-means clustering with k=%d" % nmb_clusters)
+    logging.info("embedding dimensionality is %d" % d)
 
     # faiss implementation of k-means
     clus = faiss.Clustering(d, nmb_clusters)
@@ -67,4 +71,4 @@ def run_pca(x, output_dimensionality):
     mat = faiss.PCAMatrix(x.shape[1], output_dimensionality)
     mat.train(x)
     assert mat.is_trained
-    return mat.apply_py(x)
\ No newline at end of file
+    return mat.apply_py(x)
